@@ -217,7 +217,7 @@ class Drop:
         return drop
 
 
-class GraphDrop(GraphBase):
+class DropGraph(GraphBase):
     """
     一个用于实现绘制丢包数图的类
     """
@@ -275,4 +275,4 @@ class GraphDrop(GraphBase):
 
     @staticmethod
     def parse(inputFile: str):
-        return GraphDrop(Drop.parse(inputFile))
+        return DropGraph(Drop.parse(inputFile))
